.. py:currentmodule:: rubin_sim.phot_utils

.. _rubin_sim.phot_utils:

=======================
rubin_sim photUtils
=======================

The rubin_sim.photUtils module provides synthetic photometry and SNR calculation
methods for Rubin Observatory. There are expected throughput curves available in the
'throughputs' directory of the rubin_sim data download.


Python API
==========

* :ref:`rubin_sim.phot_utils api`

* :ref:`search`